{ config, pkgs, ... }:

{
  imports =
    [
      ./hardware-configuration.nix
    ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "thompson";
  networking.networkmanager.enable = true;  # Easiest to use and most distros use this by default.

  time.timeZone = "Europe/London";

  # Enable sound.
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };

   users.users.tsv = {
     isNormalUser = true;
     extraGroups = [ 
       "wheel"
       "docker"
     ]; 
     initialPassword = "password";
   };

  services.xserver.enable = true;
  services.xserver.displayManager.sddm.enable = true;
  services.xserver.desktopManager.plasma5.enable = true;

  environment.systemPackages = with pkgs; [
    neovim
    wget
    tmux
    git
  ];

  nixpkgs.config.allowUnfree = true;

  virtualisation.docker.enable = true;

  services.openssh.enable = true;

  system.copySystemConfiguration = true;

  system.stateVersion = "22.11"; # Don't change this
}

